### v1.1.3

- Added CHANGELOG.md
- Tested with flake8, folowed most recommendations.
- Researched how to publish on conda-forge, prepared meta.yaml
    (will publish on conda in a future version)

### v1.1.2

- Stable version. Published on GitHub and PyPI.

